yakumo.nova.v2.floating_ip_dns.Resource

Package yakumo :: Package nova :: Package v2 :: Module floating_ip_dns :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

Resource class for floating IP DNS entries in Compute API v2

Instance Methods | [hide private]
None |
update(self, new_domain=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, scope=`'``__UNDEF__``'`, availability_zone=`'``__UNDEF__``'`) Update properties of a domain | source code
None |
add_entry(self, name=None, ip=None, dns_type=`'``A``'`) Add an entry | source code
None |
remove_entry(self, name=None) Remove an entry | source code
[str] |
get_entry(self, ip=None) Get DNS entries for an IP address | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, new_domain=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, scope=`'``__UNDEF__``'`, availability_zone=`'``__UNDEF__``'`) | source code
Update properties of a domain Parameters: `new_domain` (str) - New domain name `project` (yakumo.project.Resource) - Project object `scope` (str) - 'public' or 'private' `availability_zone` (str) - Availability zone name Returns: None Overrides: base.Resource.update

### add_entry(self, name=None, ip=None, dns_type=`'``A``'`) | source code
Add an entry Parameters: `name` (str) - Hostname `ip` (str) - IP address `dns_type` (str) - DNS type Returns: None

### remove_entry(self, name=None) | source code
Remove an entry Parameters: `name` (str) - Hostname Returns: None

### get_entry(self, ip=None) | source code
Get DNS entries for an IP address Parameters: `ip` (str) - IP address Returns: [str] DNS entries